@@ -1,6 +1,7 @@
 import logging
 import os
 import re
+from typing import Pattern
 from importlib import import_module
 from importlib.util import module_from_spec, spec_from_file_location
 
@@ -34,7 +35,7 @@ class Generator(object):
         self._scraped_scripts = []
         self._mixed_script = ''
 
-        def to_pattern(s: str) -> re.Pattern:
+        def to_pattern(s: str) -> Pattern:
             if s.startswith('^'):
                 return re.compile(s)
             return re.compile(f'^{s}')
@@ -63,7 +64,7 @@ class Generator(object):
 
         if is_excluded(page.url):
             self.logger.info(f'Page skipped: [{page.title}]({page.url})')
-            return f"<!-- skipped '{page}' -->"
+            return output_content
         else:
             self.logger.debug(f' (post: [{page.title}]({page.url})')
 
@@ -221,7 +222,7 @@ class Generator(object):
 
             page_path = self._page_path_for_id(page)
             h1 = soup.new_tag('h1', id=f'{page_path}')
-            h1.append(page.title)
+            h1.append(str(page.title))
             elem.insert(0, h1)
             return elem
 
